summaryrefslogtreecommitdiffstats
path: root/kioslave/sftp/process.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
commit495d08bc2db58ee7fc4ea55a7158f2f61b82fc56 (patch)
treedaabcb652c07b9a17cad88ca50b63a2d91ead4a3 /kioslave/sftp/process.cpp
parent50001f1757f97510e80cb1990e2f2d5b00144c2a (diff)
downloadtdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.tar.gz
tdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1211357 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kioslave/sftp/process.cpp')
-rw-r--r--kioslave/sftp/process.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kioslave/sftp/process.cpp b/kioslave/sftp/process.cpp
index ca99b36bb..6ef02108e 100644
--- a/kioslave/sftp/process.cpp
+++ b/kioslave/sftp/process.cpp
@@ -4,7 +4,7 @@
* This file is part of the KDE project, module kdesu.
* Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
*
* This file contains code from TEShell.C of the KDE konsole.
* Copyright (c) 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
*
* This is free software; you can use this library under the GNU Library
@@ -260,7 +260,7 @@ int MyPtyProcess::exec(TQCString command, QCStringList args)
// From now on, terminal output goes through the tty.
TQCString path;
- if (command.contains('/'))
+ if (command.tqcontains('/'))
path = command;
else
{
@@ -4,7 +4,7 @@
* Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
*
- * This file contains code from TEShell.C of the KDE konsole.
+ * This file tqcontains code from TEShell.C of the KDE konsole.
* Copyright (c) 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
*